Runs each layer in sequence, appending blueprint predictions and aggregation outputs to the dataset as it goes.
Usage
# S3 method for class 'mb_seq'
predict(object, newdata, return_all = FALSE, ...)Runs each layer in sequence, appending blueprint predictions and aggregation outputs to the dataset as it goes.
# S3 method for class 'mb_seq'
predict(object, newdata, return_all = FALSE, ...)